@@ -1,5 +1,4 @@
-import os
-import logging
+from lightwood.constants.lightwood import ColumnDataTypes
 
 import numpy as np
 import pandas as pd
@@ -82,13 +81,11 @@ class LightwoodBackend():
     def _create_lightwood_config(self):
         config = {}
 
-        #config['name'] = 'lightwood_predictor_' + self.transaction.lmd['name']
-
         config['input_features'] = []
         config['output_features'] = []
 
-        for col_name in self.transaction.input_data.columns or col_name not in self.transaction.lmd['stats_v2']:
-            if col_name in self.transaction.lmd['columns_to_ignore']:
+        for col_name in self.transaction.input_data.columns:
+            if col_name in self.transaction.lmd['columns_to_ignore'] or col_name not in self.transaction.lmd['stats_v2']:
                 continue
 
             col_stats = self.transaction.lmd['stats_v2'][col_name]
@@ -97,36 +94,39 @@ class LightwoodBackend():
 
             other_keys = {'encoder_attrs': {}}
             if data_type == DATA_TYPES.NUMERIC:
-                lightwood_data_type = 'numeric'
+                lightwood_data_type = ColumnDataTypes.NUMERIC
 
             elif data_type == DATA_TYPES.CATEGORICAL:
-                lightwood_data_type = 'categorical'
+                if data_subtype == DATA_SUBTYPES.TAGS:
+                    lightwood_data_type = ColumnDataTypes.MULTIPLE_CATEGORICAL
+                else:
+                    lightwood_data_type = ColumnDataTypes.CATEGORICAL
 
             elif data_subtype in (DATA_SUBTYPES.TIMESTAMP, DATA_SUBTYPES.DATE):
-                lightwood_data_type = 'datetime'
+                lightwood_data_type = ColumnDataTypes.DATETIME
 
             elif data_subtype == DATA_SUBTYPES.IMAGE:
-                lightwood_data_type = 'image'
+                lightwood_data_type = ColumnDataTypes.IMAGE
                 other_keys['encoder_attrs']['aim'] = 'balance'
 
             elif data_subtype == DATA_SUBTYPES.AUDIO:
-                lightwood_data_type = 'audio'
+                lightwood_data_type = ColumnDataTypes.AUDIO
 
             elif data_subtype == DATA_SUBTYPES.RICH:
-                lightwood_data_type = 'text'
+                lightwood_data_type = ColumnDataTypes.TEXT
 
             elif data_subtype == DATA_SUBTYPES.SHORT:
-                lightwood_data_type = 'short_text'
+                lightwood_data_type = ColumnDataTypes.SHORT_TEXT
 
             elif data_subtype == DATA_SUBTYPES.ARRAY:
-                lightwood_data_type = 'time_series'
+                lightwood_data_type = ColumnDataTypes.TIME_SERIES
 
             else:
                 self.transaction.log.error(f'The lightwood model backend is unable to handle data of type {data_type} and subtype {data_subtype} !')
                 raise Exception('Failed to build data definition for Lightwood model backend')
 
             if col_name in [x[0] for x in self.transaction.lmd['model_order_by']]:
-                lightwood_data_type = 'time_series'
+                lightwood_data_type = ColumnDataTypes.TIME_SERIES
 
             col_config = {
                 'name': col_name,
@@ -136,15 +136,17 @@ class LightwoodBackend():
             if data_subtype == DATA_SUBTYPES.SHORT:
                 col_config['encoder_class'] = lightwood.encoders.text.short.ShortTextEncoder
 
+
             if col_name in self.transaction.lmd['weight_map']:
                 col_config['weights'] = self.transaction.lmd['weight_map'][col_name]
 
             col_config.update(other_keys)
 
-            if col_name not in self.transaction.lmd['predict_columns']:
-                config['input_features'].append(col_config)
-            else:
+            if col_name in self.transaction.lmd['predict_columns']:
                 config['output_features'].append(col_config)
+            else:
+                config['input_features'].append(col_config)
+
 
         config['data_source'] = {}
         config['data_source']['cache_transformed_data'] = not self.transaction.lmd['force_disable_cache']
@@ -248,7 +250,7 @@ class LightwoodBackend():
             self.predictor = lightwood.Predictor(load_from_path=self.transaction.lmd['lightwood_data']['save_path'])
 
         # not the most efficient but least prone to bug and should be fast enough
-        if len(ignore_columns)  > 0:
+        if len(ignore_columns) > 0:
             run_df = df.copy(deep=True)
             for col_name in ignore_columns:
                 run_df[col_name] = [None] * len(run_df[col_name])
