@@ -208,7 +208,7 @@ class TypeDeductor(BaseModule):
             unique_tokens = set()
 
             can_be_tags = False
-            if len(data) == len([x for x in data if isinstance(x,str)]):     
+            if len(data) == len([x for x in data if isinstance(x,str)]):
                 can_be_tags = True
                 for item in data:
                     item_tags = [t.strip() for t in item.split(',')]
@@ -317,7 +317,8 @@ class TypeDeductor(BaseModule):
                                                                   col_name,
                                                                   data_subtype,
                                                                   additional_info['other_potential_subtypes'])
-            if stats_v2[col_name]['is_foreign_key'] and self.transaction.lmd['handle_foreign_keys']:
+
+            if stats_v2[col_name]['is_foreign_key'] and self.transaction.lmd['handle_foreign_keys'] and col_name not in self.transaction.lmd['predict_columns']:
                 self.transaction.lmd['columns_to_ignore'].append(col_name)
 
             if data_subtype_dist:
